You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by bm...@apache.org on 2013/05/08 02:42:20 UTC

[2/2] git commit: Updated post-reviews to work with the new git repository, by using 'master' instead of 'trunk'.

Updated post-reviews to work with the new git repository, by using
'master' instead of 'trunk'.

Review: https://reviews.apache.org/r/10968


Project: http://git-wip-us.apache.org/repos/asf/incubator-mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-mesos/commit/6947c12f
Tree: http://git-wip-us.apache.org/repos/asf/incubator-mesos/tree/6947c12f
Diff: http://git-wip-us.apache.org/repos/asf/incubator-mesos/diff/6947c12f

Branch: refs/heads/master
Commit: 6947c12f3f7a270b140eeeea7cc425c4c4773e0c
Parents: 7b629c6
Author: Benjamin Mahler <bm...@twitter.com>
Authored: Mon May 6 18:30:06 2013 -0700
Committer: Benjamin Mahler <bm...@twitter.com>
Committed: Tue May 7 17:41:42 2013 -0700

----------------------------------------------------------------------
 support/post-reviews.py |   10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-mesos/blob/6947c12f/support/post-reviews.py
----------------------------------------------------------------------
diff --git a/support/post-reviews.py b/support/post-reviews.py
index 97a1e78..8a4a333 100755
--- a/support/post-reviews.py
+++ b/support/post-reviews.py
@@ -15,9 +15,9 @@
 # http://www.reviewboard.org/docs/manual/dev/users/tools/post-review/
 #
 # $ cd /path/to/mesos
 # $ [ do some work on your branch off of trunk, make commit(s) ]
 # $ ./support/post-reviews.py --server=https://reviews.apache.org \
-#   --tracking-branch=origin/trunk --target-groups=mesos --open
+#   --tracking-branch=origin/master --target-groups=mesos --open
 #
 # NOTE: post-reviews is currently specific to Mesos development,
 # but can easily be adapted for other projects.
@@ -57,9 +57,9 @@ def execute(command, ignore_errors=False):
 # TODO(benh): Make sure this is a git repository, apologize if not.
 top_level_dir = execute(['git', 'rev-parse', '--show-toplevel']).strip()
 
-repository = 'git://git.apache.org/mesos.git'
+repository = 'https://git-wip-us.apache.org/repos/asf/incubator-mesos.git'
 
-parent_branch = 'trunk'
+parent_branch = 'master'
 
 branch_ref = execute(['git', 'symbolic-ref', 'HEAD']).strip()
 branch = branch_ref.replace('refs/heads/', '', 1)
@@ -97,7 +97,7 @@ for line in log.split('\n'):
     shas.append(sha)
 
 
-previous = 'trunk'
+previous = 'master'
 for i in range(len(shas)):
     sha = shas[i]
@@ -15,9 +15,9 @@
 #
 # $ cd /path/to/mesos
-# $ [ do some work on your branch off of trunk, make commit(s) ]
+# $ [ do some work on your branch off of master, make commit(s) ]
 # $ ./support/post-reviews.py --server=https://reviews.apache.org \